pub struct Status { /* private fields */ }Expand description
The current status of something (lockdown, serial_console), saying whether it has been enabled, disabled, or the necessary settings are only partially applied.
Implementations
Sourceimpl Status
impl Status
Sourcepub fn is_fully_enabled(&self) -> bool
pub fn is_fully_enabled(&self) -> bool
Did enabling complete successfully?
Sourcepub fn is_fully_disabled(&self) -> bool
pub fn is_fully_disabled(&self) -> bool
Did disabling complete successfuly (or thing was never enabled in the first place)?
Sourcepub fn is_partially_enabled(&self) -> bool
pub fn is_partially_enabled(&self) -> bool
Did lockdown enable/disable fail part way through, so we are partially locked?
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
A vendor specific message detailing the individual status of the parts that are needed to enable or disabled. Format of message will change, do not parse.
pub fn build_fake(enabled: EnabledDisabled) -> Self